# mypy-boto3-athena

[![PyPI - mypy-boto3-athena](https://img.shields.io/pypi/v/mypy-boto3-athena.svg?color=blue)](https://pypi.org/project/mypy-boto3-athena)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-athena.svg?color=blue)](https://pypi.org/project/mypy-boto3-athena)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Athena 1.16.5](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/athena.html#Athena) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.2.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-athena](#mypy-boto3-athena)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Athena` service.

```bash
python -m pip install boto3-stubs[athena]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[athena]` in your environment: `python -m pip install 'boto3-stubs[athena]'`

Both type checking and auto-complete should work for `Athena` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[athena]` in your environment: `python -m pip install 'boto3-stubs[athena]'`

Both type checking and auto-complete should work for `Athena` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[athena]` in your environment: `python -m pip install 'boto3-stubs[athena]'`
- Run `mypy` as usual

Type checking should work for `Athena` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[athena]` in your environment: `python -m pip install 'boto3-stubs[athena]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Athena` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`AthenaClient` provides annotations for `boto3.client("athena")`.

```python
import boto3

from mypy_boto3_athena import AthenaClient

client: AthenaClient = boto3.client("athena")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: AthenaClient = session.client("athena")
```

### Paginators annotations

`mypy_boto3_athena.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_athena import AthenaClient
from mypy_boto3_athena.paginator import (
    GetQueryResultsPaginator,
    ListDatabasesPaginator,
    ListDataCatalogsPaginator,
    ListNamedQueriesPaginator,
    ListQueryExecutionsPaginator,
    ListTableMetadataPaginator,
    ListTagsForResourcePaginator,
)

client: AthenaClient = boto3.client("athena")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_query_results_paginator: GetQueryResultsPaginator = client.get_paginator("get_query_results")
list_data_catalogs_paginator: ListDataCatalogsPaginator = client.get_paginator("list_data_catalogs")
list_databases_paginator: ListDatabasesPaginator = client.get_paginator("list_databases")
list_named_queries_paginator: ListNamedQueriesPaginator = client.get_paginator("list_named_queries")
list_query_executions_paginator: ListQueryExecutionsPaginator = client.get_paginator("list_query_executions")
list_table_metadata_paginator: ListTableMetadataPaginator = client.get_paginator("list_table_metadata")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
```







### Typed dictionations

`mypy_boto3_athena.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_athena.type_defs import (
    BatchGetNamedQueryOutputTypeDef,
    BatchGetQueryExecutionOutputTypeDef,
    ColumnInfoTypeDef,
    ColumnTypeDef,
    CreateNamedQueryOutputTypeDef,
    DatabaseTypeDef,
    DataCatalogSummaryTypeDef,
    DataCatalogTypeDef,
    DatumTypeDef,
    EncryptionConfigurationTypeDef,
    GetDatabaseOutputTypeDef,
    GetDataCatalogOutputTypeDef,
    GetNamedQueryOutputTypeDef,
    GetQueryExecutionOutputTypeDef,
    GetQueryResultsOutputTypeDef,
    GetTableMetadataOutputTypeDef,
    GetWorkGroupOutputTypeDef,
    ListDatabasesOutputTypeDef,
    ListDataCatalogsOutputTypeDef,
    ListNamedQueriesOutputTypeDef,
    ListQueryExecutionsOutputTypeDef,
    ListTableMetadataOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    ListWorkGroupsOutputTypeDef,
    NamedQueryTypeDef,
    PaginatorConfigTypeDef,
    QueryExecutionContextTypeDef,
    QueryExecutionStatisticsTypeDef,
    QueryExecutionStatusTypeDef,
    QueryExecutionTypeDef,
    ResponseMetadata,
    ResultConfigurationTypeDef,
    ResultConfigurationUpdatesTypeDef,
    ResultSetMetadataTypeDef,
    ResultSetTypeDef,
    RowTypeDef,
    StartQueryExecutionOutputTypeDef,
    TableMetadataTypeDef,
    TagTypeDef,
    UnprocessedNamedQueryIdTypeDef,
    UnprocessedQueryExecutionIdTypeDef,
    WorkGroupConfigurationTypeDef,
    WorkGroupConfigurationUpdatesTypeDef,
    WorkGroupSummaryTypeDef,
    WorkGroupTypeDef,
)

def get_structure() -> ColumnInfoTypeDef:
    return {
      ...
    }
```
